[][src]Struct flv_api_sc::spu::FlvCreateSpuGroupRequest

pub struct FlvCreateSpuGroupRequest {
    pub name: String,
    pub replicas: u16,
    pub min_id: Option<i32>,
    pub config: FlvGroupConfig,
    pub rack: Option<String>,
}

Fields

name: String

The name of the managed spu group

replicas: u16

The number of replicas for the spu group

min_id: Option<i32>

The base spu id that the spu group uses to increment the spu ids Note: Spu id is a globally unique resource and it cannot be shared

config: FlvGroupConfig

Configuration elements to be applied to each SPUs in the group

rack: Option<String>

The rack to be used for all SPUs in the group. Racks are used by replication assignment algorithm