[][src]Struct flv_api_sc::spu::FlvRegisterCustomSpuRequest

pub struct FlvRegisterCustomSpuRequest {
    pub id: i32,
    pub name: String,
    pub public_server: FlvEndPointMetadata,
    pub private_server: FlvEndPointMetadata,
    pub rack: Option<String>,
}

Fields

id: i32

The id of the custom spu (globally unique id)

name: String

The name of the custom spu

public_server: FlvEndPointMetadata

Server host and port number of the public server

private_server: FlvEndPointMetadata

Server host and port number of the private server

rack: Option<String>

Rack name (optional)