[][src]Struct flv_api_sc::topic::FetchPartitionResponse

pub struct FetchPartitionResponse {
    pub error_code: FlvErrorCode,
    pub partition_idx: i32,
    pub leader_id: i32,
    pub replicas: Vec<i32>,
    pub live_replicas: Vec<i32>,
}

Fields

error_code: FlvErrorCode

The error code, None for no errors

partition_idx: i32

The partition index.

leader_id: i32

The id of the leader SPU.

replicas: Vec<i32>

The set of all spus that host this partition.

live_replicas: Vec<i32>

The set of all live replica spus that host this partition.