[−][src]Struct flv_api_sc::spu::FlvCreateSpuGroupRequest
Fields
name: StringThe name of the managed spu group
replicas: u16The number of replicas for the spu group
min_id: Option<i32>The base spu id that the spu group uses to increment the spu ids Note: Spu id is a globally unique resource and it cannot be shared
config: FlvGroupConfigConfiguration elements to be applied to each SPUs in the group
rack: Option<String>The rack to be used for all SPUs in the group. Racks are used by replication assignment algorithm